'use strict';

var meow = require('meow');
var chalk = require('chalk');
function _interopDefaultCompat(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    default: e
  };
}
var meow__default = /*#__PURE__*/_interopDefaultCompat(meow);
var chalk__default = /*#__PURE__*/_interopDefaultCompat(chalk);
let beQuiet = false;
let beVerbose = false;
function setVerbosity(_ref) {
  let {
    verbose,
    silent
  } = _ref;
  if (silent) {
    beVerbose = false;
    beQuiet = true;
  } else if (verbose) {
    beVerbose = true;
    beQuiet = false;
  }
}
var log = {
  setVerbosity,
  msg: function (msg) {
    for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      args[_key - 1] = arguments[_key];
    }
    return !beQuiet && console.log(msg, ...args);
  },
  debug: function (msg) {
    for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
      args[_key2 - 1] = arguments[_key2];
    }
    return !beQuiet && beVerbose && console.debug("".concat(chalk__default.default.bgBlack.white("[debug]"), " ").concat(msg), ...args);
  },
  success: function (msg) {
    for (var _len3 = arguments.length, args = new Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
      args[_key3 - 1] = arguments[_key3];
    }
    return !beQuiet && console.info("".concat(chalk__default.default.bgBlack.greenBright("[success]"), " ").concat(msg), ...args);
  },
  info: function (msg) {
    for (var _len4 = arguments.length, args = new Array(_len4 > 1 ? _len4 - 1 : 0), _key4 = 1; _key4 < _len4; _key4++) {
      args[_key4 - 1] = arguments[_key4];
    }
    return !beQuiet && console.info("".concat(chalk__default.default.bgBlack.cyanBright("[info]"), " ").concat(msg), ...args);
  },
  warn: function (msg) {
    for (var _len5 = arguments.length, args = new Array(_len5 > 1 ? _len5 - 1 : 0), _key5 = 1; _key5 < _len5; _key5++) {
      args[_key5 - 1] = arguments[_key5];
    }
    return !beQuiet && console.warn("".concat(chalk__default.default.bgBlack.yellowBright("[warn]"), " ").concat(msg), ...args);
  },
  error: function (msg) {
    for (var _len6 = arguments.length, args = new Array(_len6 > 1 ? _len6 - 1 : 0), _key6 = 1; _key6 < _len6; _key6++) {
      args[_key6 - 1] = arguments[_key6];
    }
    return console.error("".concat(chalk__default.default.bgBlack.redBright("[error]"), " ").concat(msg), ...args);
  }
};
var commands = {
  init: async options => {
    await (await Promise.resolve().then(function () {
      return require('./init-2a3b4528.js');
    })).default(options);
  },
  inject: async options => {
    await (await Promise.resolve().then(function () {
      return require('./inject-f8928379.js');
    })).default(options);
  },
  "link-watch": async options => {
    await (await Promise.resolve().then(function () {
      return require('./link-watch-9e3f1174.js');
    })).default(options);
  },
  "verify-package": async options => {
    await (await Promise.resolve().then(function () {
      return require('./verify-package-73b843df.js');
    })).default(options);
  },
  "verify-studio": async options => {
    await (await Promise.resolve().then(function () {
      return require('./verify-studio-5e333969.js');
    })).default(options);
  },
  version: async options => {
    await (await Promise.resolve().then(function () {
      return require('./version-f89917d7.js');
    })).default(options);
  }
};
var sharedFlags = {
  debug: {
    default: false,
    type: "boolean"
  },
  silent: {
    type: "boolean",
    default: false
  },
  verbose: {
    type: "boolean",
    default: false
  }
};
const cliName = "@sanity/plugin-kit";
const urls = {
  refDocs: "https://beta.sanity.io/docs/reference",
  migrationGuideStudio: "https://beta.sanity.io/docs/platform/v2-to-v3",
  migrationGuidePlugin: "https://beta.sanity.io/docs/platform/v2-to-v3/plugins",
  pluginReadme: "https://github.com/sanity-io/plugin-kit",
  incompatiblePlugin: "https://github.com/sanity-io/incompatible-plugin",
  sanityExchange: "https://www.sanity.io/exchange",
  linterPackage: "https://github.com/sanity-io/eslint-config-no-v2-imports"
};
const incompatiblePluginPackage = "@sanity/incompatible-plugin";
const defaultOutDir = "dist";
async function cliEntry() {
  let argv = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : process.argv;
  let autoExit = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
  const cli = meow__default.default("\n\tUsage\n\t  $ ".concat(cliName, " [--help] [--debug] <command> [<args>]\n\n  These are common commands used in various situations:\n\n    init            Create a new Sanity plugin\n    inject          Inject config into an existing Sanity v3 plugin\n    verify-package  Check that a Sanity plugin package follows V3 conventions. Prints upgrade steps.\n    verify-studio   Check that a Sanity Studio follows V3 conventions. Prints upgrade steps.\n    link-watch      Recompiles plugin automatically on changes and runs yalc push --publish\n    version         Show the version of ").concat(cliName, " currently installed\n\n  Options\n    --silent        Do not print info and warning messages\n    --verbose       Log everything. This option conflicts with --silent\n    --debug         Print stack trace on errors\n    --version       Output the version number\n    --help          Output usage information\n\n  Examples\n    # Init a new plugin in current directory\n    $ ").concat(cliName, " init\n\n    # Init a new plugin in my-sanity-plugin directory\n    $ ").concat(cliName, " init my-sanity-plugin\n\n    # Check that a Sanity plugin package in current directory follows V3 conventions\n    $ ").concat(cliName, " verify-package\n\n    # Check that a Sanity Studio in current directory  follows V3 conventions\n    $ ").concat(cliName, " verify-studio\n"), {
    autoHelp: false,
    flags: sharedFlags,
    argv: argv.slice(2)
  });
  const commandName = cli.input[0];
  if (!commandName) {
    cli.showHelp();
  }
  if (!(commandName in commands)) {
    console.error("Unknown command \"".concat(commandName, "\""));
    cli.showHelp();
  }
  if (cli.flags.silent && cli.flags.verbose) {
    log.error("--silent and --verbose are mutually exclusive");
    cli.showHelp();
  }
  const cmd = commands[commandName];
  try {
    log.setVerbosity(cli.flags);
    await cmd({
      argv: argv.slice(3)
    });
  } catch (err) {
    log.error(err instanceof TypeError || cli.flags.debug ? err.stack : err.message);
    process.exit(1);
  }
}
exports.cliEntry = cliEntry;
exports.cliName = cliName;
exports.defaultOutDir = defaultOutDir;
exports.incompatiblePluginPackage = incompatiblePluginPackage;
exports.log = log;
exports.sharedFlags = sharedFlags;
exports.urls = urls;
//# sourceMappingURL=cli-dbe00b65.js.map
