'use strict';

var path = require('path');
var meow = require('meow');
var cli = require('./cli-dbe00b65.js');
var init = require('./init-7cd30f64.js');
var _package = require('./package-bdb22a22.js');
var execa = require('execa');
function _interopDefaultCompat(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    default: e
  };
}
var path__default = /*#__PURE__*/_interopDefaultCompat(path);
var meow__default = /*#__PURE__*/_interopDefaultCompat(meow);
var execa__default = /*#__PURE__*/_interopDefaultCompat(execa);
function npmIsAvailable() {
  return execa__default.default("npm", ["-v"]).then(() => true).catch(() => false);
}
function yarnIsAvailable() {
  return execa__default.default("yarn", ["-v"]).then(() => true).catch(() => false);
}
function pnpmAvailable() {
  return execa__default.default("pnpm", ["-v"]).then(() => true).catch(() => false);
}
async function promptForPackageManager() {
  const [npm, yarn, pnpm] = await Promise.all([npmIsAvailable(), yarnIsAvailable(), pnpmAvailable()]);
  const choices = [npm && "npm", yarn && "yarn", pnpm && "pnpm"].filter(Boolean);
  if (choices.length < 2) {
    return choices[0] || "npm";
  }
  return _package.prompt("Which package manager do you prefer?", {
    choices: choices.map(value => ({
      value,
      name: value
    })),
    default: choices[0]
  });
}
async function installDependencies(pm, _ref) {
  let {
    cwd
  } = _ref;
  const proc = execa__default.default(pm, ["install"], {
    cwd,
    stdio: "inherit"
  });
  const {
    exitCode
  } = await proc;
  return exitCode <= 0;
}
const description = "Initialize a new Sanity plugin";
const help = "\nUsage\n  $ ".concat(cli.cliName, " init [dir] [<args>]\n\nOptions\n  --no-eslint             Disables ESLint config and dependencies from being added\n  --no-prettier           Disables prettier config and dependencies from being added\n  --no-typescript         Disables typescript config and dependencies from being added\n  --no-license            Disables LICENSE + package.json license field from being added\n  --no-editorconfig       Disables .editorconfig from being added\n  --no-gitignore          Disables .gitignore from being added\n  --no-scripts            Disables scripts from being added to package.json\n  --no-install            Disables automatically running package manager install\n\n  --name [package-name]   Use the provided package-name\n  --author [name]         Use the provided author\n  --repo [url]            Use the provided repo url\n  --license [spdx]        Use the license with the given SPDX identifier\n  --force                 No promt when overwriting files\n\n  --preset [preset-name]  Adds config and files from a named preset. --preset can be supplied multiple times.\n                          The following presets are available:\n").concat(init.presetHelpList(30), "\n\nExamples\n  # Initialize a new plugin in the current directory\n  $ ").concat(cli.cliName, " init\n\n  # Initialize a plugin in the directory ~/my-plugin\n  $ ").concat(cli.cliName, " init ~/my-plugin\n\n  # Don't add eslint or prettier\n  $ ").concat(cli.cliName, " init --no-eslint --no-prettier\n");
async function run(_ref2) {
  let {
    argv
  } = _ref2;
  const cli$1 = meow__default.default(help, {
    flags: init.initFlags,
    argv,
    description
  });
  const basePath = path__default.default.resolve(cli$1.input[0] || process.cwd());
  const {
    exists,
    isRoot
  } = await _package.hasSanityJson(basePath);
  if (exists && isRoot) {
    throw new Error("sanity.json has a \"root\" property set to true - are you trying to init into a studio instead of a plugin?");
  }
  const {
    v3ConfigFile
  } = await _package.findStudioV3Config(basePath);
  if (v3ConfigFile) {
    throw new Error("".concat(v3ConfigFile, " exsists - are you trying to init into a studio instead of a plugin?"));
  }
  cli.log.info('Initializing new plugin in "%s"', basePath);
  if (!cli$1.flags.force && !(await _package.isEmptyish(basePath)) && !(await _package.prompt("Directory is not empty, proceed?", {
    type: "confirm",
    default: false
  }))) {
    cli.log.error("Directory is not empty. Cancelled.");
    return;
  }
  await _package.ensureDir(basePath);
  await init.init({
    basePath,
    flags: cli$1.flags
  });
  if (cli$1.flags.install) {
    if (await installDependencies(await promptForPackageManager(), {
      cwd: basePath
    })) {
      cli.log.info("Done!");
    } else {
      cli.log.error("Failed to install dependencies, try manually running `npm install`");
    }
  } else {
    cli.log.info("Dependency installation skipped.");
  }
}
exports.default = run;
//# sourceMappingURL=init-2a3b4528.js.map
