'use strict';

var pkgUtils = require('@sanity/pkg-utils');
var path = require('path');
var meow = require('meow');
var cli = require('./cli-dbe00b65.js');
var init = require('./init-7cd30f64.js');
var _package = require('./package-bdb22a22.js');
function _interopDefaultCompat(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    default: e
  };
}
var path__default = /*#__PURE__*/_interopDefaultCompat(path);
var meow__default = /*#__PURE__*/_interopDefaultCompat(meow);
const description = "Inject configuration into a Sanity plugin";
const help = "\nUsage\n  $ ".concat(cli.cliName, " inject [dir] [<args>]\n\nOptions\n  --no-eslint             Disables ESLint config and dependencies from being added\n  --no-prettier           Disables prettier config and dependencies from being added\n  --no-typescript         Disables typescript config and dependencies from being added\n  --no-license            Disables LICENSE + package.json license field from being added\n  --no-editorconfig       Disables .editorconfig from being added\n  --no-gitignore          Disables .gitignore from being added\n  --no-scripts            Disables scripts from being added to package.json\n\n  --license [spdx]        Use the license with the given SPDX identifier\n  --force                 No promt when overwriting files\n\n  --preset [preset-name]  Adds config and files from a named preset. --preset can be supplied multiple times.\n                          The following presets are available:\n").concat(init.presetHelpList(30), "\n  --preset-only           Skips the default inject steps. Use this to apply a preset to an otherwise complete plugin.\n\nExamples\n  # Inject configuration into the plugin in the current directory\n  $ ").concat(cli.cliName, " inject\n\n  # Inject configuration into the plugin in ~/my-plugin\n  $ ").concat(cli.cliName, " inject ~/my-plugin\n\n  # Don't inject eslint or prettier\n  $ ").concat(cli.cliName, " inject --no-eslint --no-prettier\n\n  # Inject plugin configuration and semver-workflow into the plugin in the current directory\n  $ @sanity/plugin-kit inject --preset semver-workflow\n\n  # Only inject semver-workflow and renovatebot config from presets\n  $ ").concat(cli.cliName, " inject --preset-only --preset semver-workflow --preset renovatebot\n\n");
async function run(_ref) {
  var _ref2;
  let {
    argv
  } = _ref;
  const cli$1 = meow__default.default(help, {
    flags: init.initFlags,
    argv,
    description
  });
  const basePath = path__default.default.resolve(cli$1.input[0] || process.cwd());
  const packageConfig = await pkgUtils.loadConfig({
    cwd: basePath
  });
  const outDir = (_ref2 = packageConfig == null ? void 0 : packageConfig.dist) !== null && _ref2 !== void 0 ? _ref2 : cli.defaultOutDir;
  const {
    v3ConfigFile
  } = await _package.findStudioV3Config(basePath);
  if (v3ConfigFile) {
    throw new Error("".concat(v3ConfigFile, " exists - are you trying to INJECT into a studio instead of a plugin?"));
  }
  cli.log.info('Inject config into plugin in "%s"', basePath);
  await init.inject({
    basePath,
    outDir,
    flags: cli$1.flags,
    validate: false
  });
  cli.log.info("Done!");
}
exports.default = run;
//# sourceMappingURL=inject-f8928379.js.map
