'use strict';

var name = "@sanity/plugin-kit";
var version = "3.1.0";
var description = "Enhanced Sanity.io plugin development experience";
var keywords = ["sanity-io", "sanity", "plugin", "development", "babel", "typescript", "bootstrap"];
var homepage = "https://github.com/sanity-io/plugin-kit#readme";
var bugs = {
  url: "https://github.com/sanity-io/plugin-kit/issues"
};
var repository = {
  type: "git",
  url: "git+ssh://git@github.com/sanity-io/plugin-kit.git"
};
var license = "MIT";
var author = "Sanity.io <hello@sanity.io>";
var type = "commonjs";
var exports$1 = {
  ".": {
    types: "./dist/index.d.ts",
    source: "./src/index.ts",
    require: "./dist/index.js",
    "default": "./dist/index.js"
  },
  "./package.json": "./package.json"
};
var main = "./dist/index.js";
var source = "./src/index.ts";
var types = "./dist/index.d.ts";
var bin = {
  "plugin-kit": "./bin/plugin-kit.js"
};
var files = ["assets", "bin", "dist", "src", "v2-incompatible.js"];
var scripts = {
  build: "run-s clean && pkg-utils build --strict && pkg-utils --strict",
  clean: "rimraf dist",
  commit: "git-cz",
  compile: "tsc --build",
  format: "prettier src -w",
  lint: "eslint .",
  prepare: "husky install",
  prepublishOnly: "run-s build",
  test: "tap",
  watch: "pkg-utils watch --strict"
};
var tap = {
  browser: false,
  "check-coverage": false,
  "coverage-report": ["html"],
  jobs: 2,
  reporter: "spec",
  "test-ignore": "^dist/.*|.*ignore.*|.*run-test-command.*|.*fixture.utils.*",
  timeout: 120,
  ts: true
};
var dependencies = {
  "@rexxars/choosealicense-list": "^1.1.2",
  "@sanity/pkg-utils": "^2.1.0",
  chalk: "^4.1.2",
  concurrently: "^7.5.0",
  "discover-path": "^1.0.0",
  "email-validator": "^2.0.4",
  execa: "^5.1.1",
  "find-babel-config": "^1.2.0",
  "get-it": "^7.0.2",
  "get-latest-version": "^4.0.0",
  "git-remote-origin-url": "^3.1.0",
  "git-user-info": "^2.0.3",
  "github-url-to-object": "^4.0.6",
  inquirer: "^8.2.5",
  meow: "^9.0.0",
  nodemon: "^2.0.20",
  "npm-packlist": "^7.0.2",
  "npm-run-path": "^4.0.1",
  outdent: "^0.8.0",
  "p-any": "^3.0.0",
  "p-props": "^4.0.0",
  postcss: "^8.4.19",
  rimraf: "^3.0.2",
  semver: "^7.3.8",
  "spdx-license-ids": "^3.0.12",
  "validate-npm-package-name": "^5.0.0",
  "xdg-basedir": "^4.0.0",
  yalc: "^1.0.0-pre.53"
};
var devDependencies = {
  "@commitlint/cli": "^17.2.0",
  "@commitlint/config-conventional": "^17.2.0",
  "@sanity/semantic-release-preset": "^2.0.2",
  "@sanity/ui-workshop": "^1.0.1",
  "@types/eslint": "^8.4.10",
  "@types/fs-extra": "^9.0.13",
  "@types/inquirer": "^9.0.3",
  "@types/node": "^18.11.9",
  "@types/nodemon": "^1.19.2",
  "@types/tap": "^15.0.7",
  "@typescript-eslint/eslint-plugin": "^5.43.0",
  "@typescript-eslint/parser": "^5.43.0",
  eslint: "^8.27.0",
  "eslint-config-prettier": "^8.5.0",
  "eslint-config-sanity": "^6.0.0",
  "eslint-plugin-prettier": "^4.2.1",
  "eslint-plugin-react-hooks": "^4.6.0",
  "fs-extra": "^10.1.0",
  husky: "^8.0.2",
  json5: "^2.2.1",
  "lint-staged": "^13.0.3",
  "npm-run-all": "^4.1.5",
  prettier: "^2.7.1",
  "prettier-plugin-packagejson": "^2.3.0",
  readdirp: "^3.6.0",
  rimraf: "^3.0.2",
  sanity: "^3.0.0",
  sinon: "^14.0.2",
  tap: "^16.3.1",
  "ts-node": "^10.9.1",
  typescript: "^4.9.4"
};
var peerDependencies = {
  eslint: ">=8.0.0"
};
var engines = {
  node: ">=14"
};
var binname = "sanity-plugin";
var pkg = {
  name: name,
  version: version,
  description: description,
  keywords: keywords,
  homepage: homepage,
  bugs: bugs,
  repository: repository,
  license: license,
  author: author,
  type: type,
  exports: exports$1,
  main: main,
  source: source,
  types: types,
  bin: bin,
  files: files,
  scripts: scripts,
  tap: tap,
  dependencies: dependencies,
  devDependencies: devDependencies,
  peerDependencies: peerDependencies,
  engines: engines,
  binname: binname
};
exports.pkg = pkg;
//# sourceMappingURL=package-f79f12a7.js.map
