'use strict';

var _templateObject, _templateObject2, _templateObject3, _templateObject4;
function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
var cli = require('./cli-dbe00b65.js');
var _package = require('./package-bdb22a22.js');
var eslint = require('eslint');
var path = require('path');
var outdent = require('outdent');
require('fs');
var chalk = require('chalk');
var childProcess = require('child_process');
var npmRunPath = require('npm-run-path');
var pkgUtils = require('@sanity/pkg-utils');
function _interopDefaultCompat(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    default: e
  };
}
var path__default = /*#__PURE__*/_interopDefaultCompat(path);
var outdent__default = /*#__PURE__*/_interopDefaultCompat(outdent);
var chalk__default = /*#__PURE__*/_interopDefaultCompat(chalk);
var childProcess__default = /*#__PURE__*/_interopDefaultCompat(childProcess);
var npmRunPath__default = /*#__PURE__*/_interopDefaultCompat(npmRunPath);
const removedImportSuffix = "imports where removed in Sanity v3. Please refer to the migration guide: ".concat(cli.urls.migrationGuideStudio, ", or new API-reference docs: ").concat(cli.urls.refDocs);
async function validateImports(_ref) {
  let {
    basePath
  } = _ref;
  cli.log.debug("Running ESLint with Sanity Studio import hints...");
  const eslint$1 = new eslint.ESLint({
    cwd: basePath,
    overrideConfig: {
      ignorePatterns: ["node_modules"],
      rules: {
        "no-restricted-imports": ["error", {
          patterns: [..._package.mergedPackages.map(packageName => ({
            group: ["".concat(packageName, "*")],
            message: "Use sanity instead of ".concat(packageName, ".")
          })), {
            group: ["config:*"],
            message: "config: imports are no longer supported. Please see the new plugin API for alternatives: ".concat(cli.urls.migrationGuideStudio)
          }, {
            group: ["part:*"],
            message: "part: ".concat(removedImportSuffix)
          }, {
            group: ["all:part:*"],
            message: "all:part: ".concat(removedImportSuffix)
          }, {
            group: ["sanity:*"],
            message: "sanity: ".concat(removedImportSuffix)
          }]
        }]
      }
    }
  });
  try {
    const results = await eslint$1.lintFiles([path__default.default.join(basePath, "**/*.{js,jsx,ts,tsx}")]);
    const onlyImportErrors = results.map(r => {
      const limitErrors = r.messages.filter(m => m.ruleId === "no-restricted-imports");
      return _objectSpread(_objectSpread({}, r), {}, {
        messages: limitErrors,
        errorCount: limitErrors.length
      });
    }).filter(r => r.errorCount);
    if (onlyImportErrors.length) {
      const formatter = await eslint$1.loadFormatter("stylish");
      const resultText = await formatter.format(onlyImportErrors);
      const addtionalInfo = outdent__default.default(_templateObject || (_templateObject = _taggedTemplateLiteral(["\n        ESLint detected Studio V2 imports that are no longer available.\n        It is recommended configure @sanity/eslint-config-no-v2-imports for ESLint.\n\n        Run:\n        npm install --save-dev @sanity/eslint-config-no-v2-imports\n\n        In .eslintrc add:\n        \"extends\": [\"@sanity/no-v2-imports\"]\n\n        This way, V2-imports can be identified directly in the IDE, or using eslint CLI.\n        For more, see ", "\n\n        If the plugin package does not use eslint, disable this check.\n    "])), cli.urls.linterPackage);
      return [resultText + addtionalInfo];
    }
  } catch (e) {
    cli.log.error("Failed to run eslint check", e);
    return [outdent__default.default(_templateObject2 || (_templateObject2 = _taggedTemplateLiteral(["\n        Failed to run ESLint. Is ESLint configured?\n        It is recommended to install eslint-config-sanity and add 'sanity/upgrade-v2' to your eslint-extends config.\n\n        Run:\n        npm install --save-dev eslint-config-sanity\n\n        In .eslintrc add:\n        extends: ['sanity/upgrade-v2']\n\n        This way, V2-imports can be identified directly in the IDE, or using eslint CLI.\n        If the package does not use eslint, disable this check.\n    "])))];
  }
  return [];
}
function parseCommand(commandString) {
  const normalized = commandString.replace(/ +/g, " ");
  const commandAndArg = normalized.split(" ");
  return {
    command: commandAndArg[0],
    args: commandAndArg.length > 1 ? commandAndArg.slice(1) : []
  };
}
async function runCommand(commandString) {
  cli.log.info("Running command: ".concat(commandString));
  const {
    command,
    args
  } = parseCommand(commandString);
  let options = {
    stdio: "inherit",
    env: npmRunPath__default.default.env()
  };
  options = process.platform === "win32" ? _objectSpread(_objectSpread({}, options), {}, {
    shell: true
  }) : options;
  return new Promise((resolve, reject) => {
    childProcess__default.default.spawn(command, args, options).on("error", reject).on("close", exitCode => {
      resolve({
        code: exitCode !== null && exitCode !== void 0 ? exitCode : 0
      });
    });
  });
}
const splitLine = "\n----------------------------------------------------------";
const verifyFlags = _objectSpread(_objectSpread({}, cli.sharedFlags), {}, {
  single: {
    default: false,
    type: "boolean"
  }
});
function disableCheckText(checkKey) {
  return chalk__default.default.grey(outdent__default.default(_templateObject3 || (_templateObject3 = _taggedTemplateLiteral(["\n              To skip this validation add the following to your package.json:\n              \"sanityPlugin\": {\n                 \"verifyPackage\": {\n                    \"", "\": false\n                 }\n              }\n          "])), checkKey).trimStart());
}
function createValidator(verifyConfig, flags, errors) {
  return async function validation(checkKey, task) {
    if (verifyConfig[checkKey] !== false) {
      const result = await task();
      if (result == null ? void 0 : result.length) {
        result.push(disableCheckText(checkKey));
        const errorMessage = result.join("\n\n");
        errors.push(errorMessage);
        cli.log.error("\n" + errorMessage + splitLine);
      }
    }
    if (flags.single && errors.length) {
      throw new Error(outdent__default.default(_templateObject4 || (_templateObject4 = _taggedTemplateLiteral(["Detected outstanding upgrade issues.\n\n        Fail-fast (--single) mode enabled, stopping validation here.\n        "]))));
    }
  };
}
async function runTscMaybe(verifyConfig, ts) {
  if (ts && verifyConfig.tsc !== false) {
    cli.log.info("All checks ok, running Typescript compiler.");
    const {
      code
    } = await runCommand("tsc --build");
    if (code !== 0) {
      throw new Error("Compilation failed. See output above.\n\n" + disableCheckText("tsc"));
    }
  }
}
async function readTSConfig(options) {
  const {
    basePath,
    filename
  } = options;
  const filePath = path__default.default.resolve(basePath, filename);
  const exists = await _package.fileExists(filePath);
  if (!exists) return void 0;
  return await pkgUtils.loadTSConfig({
    cwd: basePath,
    tsconfigPath: filename
  });
}
exports.createValidator = createValidator;
exports.readTSConfig = readTSConfig;
exports.runTscMaybe = runTscMaybe;
exports.validateImports = validateImports;
exports.verifyFlags = verifyFlags;
//# sourceMappingURL=ts-5747e004.js.map
