'use strict';

var _templateObject, _templateObject2;
function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }
var path = require('path');
var meow = require('meow');
var pkgUtils = require('@sanity/pkg-utils');
var _package = require('./package-bdb22a22.js');
var cli = require('./cli-dbe00b65.js');
var ts = require('./ts-5747e004.js');
var outdent = require('outdent');
var chalk = require('chalk');
function _interopDefaultCompat(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    default: e
  };
}
var path__default = /*#__PURE__*/_interopDefaultCompat(path);
var meow__default = /*#__PURE__*/_interopDefaultCompat(meow);
var outdent__default = /*#__PURE__*/_interopDefaultCompat(outdent);
var chalk__default = /*#__PURE__*/_interopDefaultCompat(chalk);
async function verifyPackage(_ref) {
  var _ref2, _ref3;
  let {
    basePath,
    flags
  } = _ref;
  var _a;
  let errors = [];
  const packageJson = await _package.getPackage({
    basePath,
    validate: false
  });
  const verifyConfig = ((_a = packageJson.sanityPlugin) == null ? void 0 : _a.verifyPackage) || {};
  const packageConfig = await pkgUtils.loadConfig({
    cwd: basePath
  });
  const outDir = (_ref2 = packageConfig == null ? void 0 : packageConfig.dist) !== null && _ref2 !== void 0 ? _ref2 : cli.defaultOutDir;
  const tsconfig = (_ref3 = packageConfig == null ? void 0 : packageConfig.tsconfig) !== null && _ref3 !== void 0 ? _ref3 : "tsconfig.json";
  const validation = ts.createValidator(verifyConfig, flags, errors);
  const ts$1 = await ts.readTSConfig({
    basePath,
    filename: tsconfig
  });
  await validation("packageName", async () => _package.validatePackageName(packageJson));
  await validation("pkg-utils", async () => _package.validatePkgUtilsDependency(packageJson));
  await validation("srcIndex", async () => _package.validateSrcIndexFile(basePath));
  await validation("scripts", async () => _package.validateScripts(packageJson));
  await validation("module", async () => _package.validateModule(packageJson, {
    outDir
  }));
  await validation("nodeEngine", async () => _package.validateNodeEngine(packageJson));
  await validation("duplicateConfig", async () => _package.disallowDuplicateEslintConfig(basePath, packageJson));
  await validation("duplicateConfig", async () => _package.disallowDuplicatePrettierConfig(basePath, packageJson));
  if (ts$1) {
    await validation("tsconfig", async () => _package.validateTsConfig(ts$1, {
      basePath,
      outDir,
      tsconfig
    }));
  }
  await validation("sanityV2Json", async () => _package.validatePluginSanityJson({
    basePath,
    packageJson
  }));
  await validation("babelConfig", async () => _package.validateBabelConfig({
    basePath
  }));
  await validation("dependencies", async () => _package.validateSanityDependencies(packageJson));
  await validation("deprecatedDependencies", async () => _package.validateDeprecatedDependencies(packageJson));
  await validation("eslintImports", async () => ts.validateImports({
    basePath
  }));
  if (errors.length) {
    throw new Error(outdent__default.default(_templateObject || (_templateObject = _taggedTemplateLiteral(["\n        Detected validation issues!\n        To make this package Sanity v3 compatible, fix the issues starting from the top, or disable any checks you deem unnecessary.\n\n        These issues assume the package uses @sanity/plugin-kit defaults for development and building.\n        Refer to ", " for configuration options.\n\n        More information is available here:\n        - Studio migration guide: ", "\n        - Plugin migration guide: ", "\n        - Reference documentation: ", "\n\n        ", "\n      "])), cli.urls.pluginReadme, cli.urls.migrationGuideStudio, cli.urls.migrationGuidePlugin, cli.urls.refDocs, chalk__default.default.grey("To fail-fast on first detected issue run:\nnpx ".concat(cli.cliName, " verify-package' --single"))).trimStart());
  }
  await ts.runTscMaybe(verifyConfig, ts$1);
  cli.log.success(outdent__default.default(_templateObject2 || (_templateObject2 = _taggedTemplateLiteral(["\n    No outstanding upgrade issues detected.\n\n    Suggested next steps:\n      - Use plugin-kit to build and develop the plugin according to ", ".\n      - Build the plugin and fix any compilation errors\n      - Test the plugin using the link-watch command\n  "])), cli.urls.pluginReadme).trim());
}
const description = "Verify that a Sanity plugin package is v3 compatible, and print upgrade steps if not.";
const help = "\nUsage\n  $ ".concat(cli.cliName, " verify-package [dir] [<args>]\n\nOptions\n  --single      Enables fail-fast mode: Will only output the first validation that fails.\n  --silent      Do not print info and warning messages\n  --verbose     Log everything. This option conflicts with --silent\n  --version     Output the version number\n  --help        Output usage information\n\nEach check will describe how they can be individually disabled.\n\nExamples\n  # Verify Sanity plugin package in current directory\n  $ ").concat(cli.cliName, " verify-package\n\n  # Verify Sanity plugin package in my-plugin directory in silent mode\n  $ ").concat(cli.cliName, " verify-package my-plugin-directory --silent\n");
function run(_ref4) {
  let {
    argv
  } = _ref4;
  const cli = meow__default.default(help, {
    flags: ts.verifyFlags,
    argv,
    description
  });
  const basePath = path__default.default.resolve(cli.input[0] || process.cwd());
  return verifyPackage({
    basePath,
    flags: cli.flags
  });
}
exports.default = run;
//# sourceMappingURL=verify-package-73b843df.js.map
