'use strict';

var _templateObject, _templateObject2;
function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }
var path = require('path');
var meow = require('meow');
var cli = require('./cli-dbe00b65.js');
var ts = require('./ts-5747e004.js');
var pkgUtils = require('@sanity/pkg-utils');
var _package = require('./package-bdb22a22.js');
var outdent = require('outdent');
var chalk = require('chalk');
function _interopDefaultCompat(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    default: e
  };
}
var path__default = /*#__PURE__*/_interopDefaultCompat(path);
var meow__default = /*#__PURE__*/_interopDefaultCompat(meow);
var outdent__default = /*#__PURE__*/_interopDefaultCompat(outdent);
var chalk__default = /*#__PURE__*/_interopDefaultCompat(chalk);
async function verifyStudio(_ref) {
  var _ref2;
  let {
    basePath,
    flags
  } = _ref;
  var _a;
  let errors = [];
  const packageJson = await _package.getPackage({
    basePath,
    validate: false
  });
  const verifyConfig = ((_a = packageJson.sanityPlugin) == null ? void 0 : _a.verifyPackage) || {};
  const packageConfig = await pkgUtils.loadConfig({
    cwd: basePath
  });
  const tsconfig = (_ref2 = packageConfig == null ? void 0 : packageConfig.tsconfig) !== null && _ref2 !== void 0 ? _ref2 : "tsconfig.json";
  const validation = ts.createValidator(verifyConfig, flags, errors);
  const ts$1 = await ts.readTSConfig({
    basePath,
    filename: tsconfig
  });
  await validation("studioConfig", async () => _package.validateStudioConfig({
    basePath
  }));
  await validation("dependencies", async () => _package.validateSanityDependencies(packageJson));
  await validation("eslintImports", async () => ts.validateImports({
    basePath
  }));
  if (errors.length) {
    throw new Error(outdent__default.default(_templateObject || (_templateObject = _taggedTemplateLiteral(["\n        Detected validation issues!\n        This Sanity Studio is not completely V3 ready. Fix the issues starting from the top, or disable any checks you deem unnecessary.\n\n        More information is available here:\n        - Migration guide: ", "\n        - Reference documentation: ", "\n\n        ", "\n      "])), cli.urls.migrationGuideStudio, cli.urls.refDocs, chalk__default.default.grey("To fail-fast on first detected issue run:\nnpx ".concat(cli.cliName, " verify-studio --single"))).trimStart());
  }
  await ts.runTscMaybe(verifyConfig, ts$1);
  cli.log.success(outdent__default.default(_templateObject2 || (_templateObject2 = _taggedTemplateLiteral(["\n    No outstanding upgrade issues detected. Studio is V3 ready!\n  "]))).trim());
}
const description = "Verify that a Sanity Studio is configured correctly for v3, and print upgrade steps if not.";
const help = "\nUsage\n  $ ".concat(cli.cliName, " verify-studio [dir] [<args>]\n\nOptions\n  --single      Enables fail-fast mode: Will only output the first validation that fails.\n  --silent      Do not print info and warning messages\n  --verbose     Log everything. This option conflicts with --silent\n  --version     Output the version number\n  --help        Output usage information\n\nEach check will describe how they can be individually disabled.\n\nExamples\n  # Verify Sanity Studio in current directory\n  $ ").concat(cli.cliName, " verify-studio\n\n  # Verify Sanity Studio in my-sanity-studio directory in silent mode\n  $ ").concat(cli.cliName, " verify-studio my-sanity-studio --silent\n");
function run(_ref3) {
  let {
    argv
  } = _ref3;
  const cli = meow__default.default(help, {
    flags: ts.verifyFlags,
    argv,
    description
  });
  const basePath = path__default.default.resolve(cli.input[0] || process.cwd());
  return verifyStudio({
    basePath,
    flags: cli.flags
  });
}
exports.default = run;
//# sourceMappingURL=verify-studio-5e333969.js.map
